Cypress.Commands.addQuery('findToolbarButtonByText', function (text, options) {
    return (subject) => {
        if (subject !== undefined && !subject?.[0]?.hasAttribute('ui5-toolbar')) {
            const err = `findToolbarButtonByText() needs to be chained to a \`ui5-toolbar\`, or not be chained at all.`;
            throw new TypeError(err);
        }
        const container = subject ? [subject[0]] : document.querySelectorAll('[ui5-toolbar]');
        const toolbarBtns = [];
        container.forEach((el) => {
            if (el) {
                const toolbarDom = el.getDomRef();
                const buttons = Cypress.$(toolbarDom).find('[ui5-button]');
                const matchingButtons = buttons.filter(function () {
                    return Cypress.$(this).text() === text;
                });
                toolbarBtns.push(...matchingButtons);
            }
        });
        if (toolbarBtns.length > 1) {
            const err = `Multiple ui5-toolbar-button elements with the same text ("${text}") were found.`;
            throw new TypeError(err);
        }
        let toolbarBtn = toolbarBtns[0];
        if (options?.queryShadowButton) {
            toolbarBtn = toolbarBtn.shadowRoot.querySelector('button');
        }
        return Cypress.$(toolbarBtn);
    };
});
Cypress.Commands.addQuery('findShadowInput', function () {
    const getShadow = cy.now('shadow');
    const getInput = cy.now('find', 'input');
    return (subject) => {
        if (!subject?.[0].tagName.startsWith('UI5')) {
            const err = `findShadowInput() needs to be chained to a ui5-webcomponent`;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const shadow = getShadow(subject);
        // @ts-expect-error: recommended approach per cypress docs
        return getInput(shadow);
    };
});
Cypress.Commands.addQuery('findUi5TabByText', function (text) {
    const getTabList = cy.now('find', '[role="tablist"]');
    const getText = cy.now('contains', text);
    const getParent = cy.now('parents', '[role="tab"]');
    return (subject) => {
        if (!subject?.[0]?.hasAttribute('ui5-tabcontainer')) {
            const err = `findUi5TabByText() needs to be chained to a \`ui5-tabcontainer\``;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const tabList = getTabList(subject);
        // @ts-expect-error: recommended approach per cypress docs
        const text = getText(tabList);
        // @ts-expect-error: recommended approach per cypress docs
        const parent = getParent(text);
        return parent;
    };
});
Cypress.Commands.addQuery('findUi5TabOpenPopoverButtonByText', function (text) {
    const getTabList = cy.now('find', '[role="tablist"]');
    const getText = cy.now('contains', text);
    const getParent = cy.now('parents', '[role="tab"]');
    const getButton = cy.now('find', '[ui5-button]');
    return (subject) => {
        if (!subject?.[0]?.hasAttribute('ui5-tabcontainer')) {
            const err = `findUi5TabOpenPopoverButtonByText() needs to be chained to a \`ui5-tabcontainer\``;
            throw new TypeError(err);
        }
        // @ts-expect-error: recommended approach per cypress docs
        const tabList = getTabList(subject);
        // @ts-expect-error: recommended approach per cypress docs
        const text = getText(tabList);
        // @ts-expect-error: recommended approach per cypress docs
        const parent = getParent(text);
        // @ts-expect-error: recommended approach per cypress docs
        const button = getButton(parent);
        return button;
    };
});
export {};
